@@ -7,8 +7,9 @@
 import sys
 import math
 import traceback
+from collections import OrderedDict
 
-import numpy
+import numpy as np
 
 from ginga.util import wcsmod, io_fits
 from ginga.util import wcs, iqcalc
@@ -86,11 +87,11 @@ class AstroImage(BaseImage):
     def setup_data(self, data, naxispath=None):
         # initialize data attribute to something reasonable
         if data is None:
-            data = numpy.zeros((0, 0))
-        elif not isinstance(data, numpy.ndarray):
-            data = numpy.zeros((0, 0))
+            data = np.zeros((0, 0))
+        elif not isinstance(data, np.ndarray):
+            data = np.zeros((0, 0))
         elif 0 in data.shape:
-            data = numpy.zeros((0, 0))
+            data = np.zeros((0, 0))
         elif len(data.shape) < 2:
             # Expand 1D arrays into 1xN array
             data = data.reshape((1, data.shape[0]))
@@ -100,7 +101,7 @@ class AstroImage(BaseImage):
 
         # this will get reset in set_naxispath() if array is
         # multidimensional
-        self._data = data
+        self._data = self._md_data
 
         if naxispath is None:
             naxispath = []
@@ -144,6 +145,28 @@ class AstroImage(BaseImage):
         if hasattr(self, 'wcs') and self.wcs is not None:
             self.wcs.load_header(hdu.header, fobj=fobj)
 
+    def load_nddata(self, ndd, naxispath=None):
+        """Load from an astropy.nddata.NDData object.
+        """
+        self.clear_metadata()
+
+        # Make a header based on any NDData metadata
+        ahdr = self.get_header()
+        ahdr.update(ndd.meta)
+
+        self.setup_data(ndd.data, naxispath=naxispath)
+
+        if ndd.wcs is None:
+            # no wcs in ndd obj--let's try to make one from the header
+            self.wcs = wcsmod.WCS(logger=self.logger)
+            self.wcs.load_header(ahdr)
+        else:
+            # already have a valid wcs in the ndd object
+            # we assume it needs an astropy compatible wcs
+            wcsinfo = wcsmod.get_wcs_class('astropy')
+            self.wcs = wcsinfo.wrapper_class(logger=self.logger)
+            self.wcs.load_nddata(ndd)
+
     def load_file(self, filespec, **kwargs):
 
         if self.io is None:
@@ -162,7 +185,7 @@ class AstroImage(BaseImage):
 
     def load_buffer(self, buf, dims, dtype, byteswap=False,
                     naxispath=None, metadata=None):
-        data = numpy.fromstring(buf, dtype=dtype)
+        data = np.fromstring(buf, dtype=dtype)
         if byteswap:
             data.byteswap(True)
         data = data.reshape(dims)
@@ -179,7 +202,7 @@ class AstroImage(BaseImage):
         revnaxis.reverse()
 
         # construct slice view and extract it
-        view = revnaxis + [slice(None), slice(None)]
+        view = tuple(revnaxis + [slice(None), slice(None)])
         data = self.get_mddata()[view]
 
         if len(data.shape) != 2:
@@ -305,6 +328,48 @@ class AstroImage(BaseImage):
         self.transfer(other, astype=astype)
         return other
 
+    def as_nddata(self, nddata_class=None):
+        "Return a version of ourself as an astropy.nddata.NDData object"
+        if nddata_class is None:
+            from astropy.nddata import NDData
+            nddata_class = NDData
+
+        # transfer header, preserving ordering
+        ahdr = self.get_header()
+        header = OrderedDict(ahdr.items())
+        data = self.get_mddata()
+
+        wcs = None
+        if hasattr(self, 'wcs') and self.wcs is not None:
+            # for now, assume self.wcs wraps an astropy wcs object
+            wcs = self.wcs.wcs
+
+        ndd = nddata_class(data, wcs=wcs, meta=header)
+        return ndd
+
+    def as_hdu(self):
+        "Return a version of ourself as an astropy.io.fits.PrimaryHDU object"
+        from astropy.io import fits
+
+        # transfer header, preserving ordering
+        ahdr = self.get_header()
+        header = fits.Header(ahdr.items())
+        data = self.get_mddata()
+
+        hdu = fits.PrimaryHDU(data=data, header=header)
+        return hdu
+
+    def astype(self, type_name):
+        """Convert AstroImage object to some other kind of object.
+        """
+        if type_name == 'nddata':
+            return self.as_nddata()
+
+        if type_name == 'hdu':
+            return self.as_hdu()
+
+        raise ValueError("Unrecognized conversion type '%s'" % (type_name))
+
     def save_as_file(self, filepath, **kwdargs):
         data = self._get_data()
         header = self.get_header()
@@ -334,7 +399,8 @@ class AstroImage(BaseImage):
         return self.wcs.radectopix(ra_deg, dec_deg, coords=coords,
                                    naxispath=self.revnaxis)
 
-    # -----> TODO: merge into wcs.py ?
+    # -----> TODO:
+    #   This section has been merged into util.wcs.  Deprecate it here.
     #
     def get_starsep_XY(self, x1, y1, x2, y2):
         # source point
@@ -426,7 +492,7 @@ class AstroImage(BaseImage):
 
         return self.calc_compass_radius(x, y, radius_px)
     #
-    # <----- TODO: merge this into wcs.py ?
+    # <----- TODO: deprecate
 
     def get_wcs_rotation_deg(self):
         header = self.get_header()
@@ -492,8 +558,8 @@ class AstroImage(BaseImage):
 
             # Determine max/min to update our values
             if update_minmax:
-                maxval = numpy.nanmax(data_np)
-                minval = numpy.nanmin(data_np)
+                maxval = np.nanmax(data_np)
+                minval = np.nanmin(data_np)
                 self.maxval = max(self.maxval, maxval)
                 self.minval = min(self.minval, minval)
 
@@ -506,8 +572,8 @@ class AstroImage(BaseImage):
 
             # scale if necessary
             # TODO: combine with rotation?
-            if (not numpy.isclose(math.fabs(cdelt1), scale_x) or
-                    not numpy.isclose(math.fabs(cdelt2), scale_y)):
+            if (not np.isclose(math.fabs(cdelt1), scale_x) or
+                not np.isclose(math.fabs(cdelt2), scale_y)):
                 nscale_x = math.fabs(cdelt1) / scale_x
                 nscale_y = math.fabs(cdelt2) / scale_y
                 self.logger.debug("scaling piece by x(%f), y(%f)" % (
@@ -523,8 +589,8 @@ class AstroImage(BaseImage):
             flip_y = False
 
             # Optomization for 180 rotations
-            if (numpy.isclose(math.fabs(rot_dx), 180.0) or
-                    numpy.isclose(math.fabs(rot_dy), 180.0)):
+            if (np.isclose(math.fabs(rot_dx), 180.0) or
+                np.isclose(math.fabs(rot_dy), 180.0)):
                 rotdata = trcalc.transform(data_np,
                                            flip_x=True, flip_y=True)
                 rot_dx = 0.0
@@ -533,7 +599,7 @@ class AstroImage(BaseImage):
                 rotdata = data_np
 
             # Finish with any necessary rotation of piece
-            if not numpy.isclose(rot_dy, 0.0):
+            if not np.isclose(rot_dy, 0.0):
                 rot_deg = rot_dy
                 self.logger.debug("rotating %s by %f deg" % (name, rot_deg))
                 rotdata = trcalc.rotate(rotdata, rot_deg,
@@ -541,11 +607,11 @@ class AstroImage(BaseImage):
                                         logger=self.logger)
 
             # Flip X due to negative CDELT1
-            if numpy.sign(cdelt1) != numpy.sign(cdelt1_ref):
+            if np.sign(cdelt1) != np.sign(cdelt1_ref):
                 flip_x = True
 
             # Flip Y due to negative CDELT2
-            if numpy.sign(cdelt2) != numpy.sign(cdelt2_ref):
+            if np.sign(cdelt2) != np.sign(cdelt2_ref):
                 flip_y = True
 
             if flip_x or flip_y:
@@ -619,7 +685,7 @@ class AstroImage(BaseImage):
                                     (expand_pct * 100, max_expand_pct))
 
                 # go for it!
-                new_data = numpy.zeros((new_ht, new_wd))
+                new_data = np.zeros((new_ht, new_wd))
                 # place current data into new data
                 new_data[ny1_off:ny1_off + myht, nx1_off:nx1_off + mywd] = \
                     mydata
