@@ -6,8 +6,10 @@
 #
 import numpy as np
 
-from ginga.misc import Callback
-from ginga import ColorDist
+from ginga.misc import Callback, Settings
+from ginga import ColorDist, trcalc
+from ginga import cmap as mod_cmap
+from ginga import imap as mod_imap
 
 
 class RGBMapError(Exception):
@@ -58,10 +60,8 @@ class RGBPlanes(object):
         if order == self.order:
             return self.rgbarr.astype(dtype, copy=False)
 
-        l = [self.get_slice(c) for c in order]
-        res = np.concatenate([arr[..., np.newaxis].astype(dtype, copy=False,
-                                                          casting='unsafe')
-                              for arr in l], axis=-1)
+        res = trcalc.reorder_image(order, self.rgbarr, self.order)
+        res = res.astype(dtype, copy=False, casting='unsafe')
         return res
 
     def get_size(self):
@@ -79,11 +79,39 @@ class RGBMapper(Callback.Callbacks):
     # result
     #
 
-    def __init__(self, logger, dist=None, bpp=None):
+    def __init__(self, logger, dist=None, settings=None, bpp=None):
         Callback.Callbacks.__init__(self)
 
         self.logger = logger
 
+        # Create settings and set defaults
+        if settings is None:
+            settings = Settings.SettingGroup(logger=self.logger)
+        self.settings = settings
+        self.t_ = settings
+        self.settings_keys = ['color_map', 'intensity_map',
+                              'color_array', 'shift_array',
+                              'color_algorithm', 'color_hashsize',
+                              ]
+
+        # add our defaults
+        self.t_.add_defaults(color_map='gray', intensity_map='ramp',
+                             color_algorithm='linear',
+                             color_hashsize=65535,
+                             color_array=None, shift_array=None)
+        self.t_.get_setting('color_map').add_callback('set',
+                                                      self.color_map_set_cb)
+        self.t_.get_setting('intensity_map').add_callback('set',
+                                                          self.intensity_map_set_cb)
+        self.t_.get_setting('color_array').add_callback('set',
+                                                        self.color_array_set_cb)
+        self.t_.get_setting('shift_array').add_callback('set',
+                                                        self.shift_array_set_cb)
+        self.t_.get_setting('color_hashsize').add_callback('set',
+                                                           self.color_hashsize_set_cb)
+        self.t_.get_setting('color_algorithm').add_callback('set',
+                                                            self.color_algorithm_set_cb)
+
         # For color and intensity maps
         self.cmap = None
         self.imap = None
@@ -92,8 +120,6 @@ class RGBMapper(Callback.Callbacks):
         self.carr = None
         self.sarr = None
         self.scale_pct = 1.0
-        # length of the color map
-        self.maxc = 255
 
         # targeted bit depth per-pixel band of the output RGB array
         # (can be less than the data size of the output array)
@@ -101,22 +127,42 @@ class RGBMapper(Callback.Callbacks):
             bpp = 8
         self.bpp = bpp
         # maximum value that we can generate in this range
-        self.maxv = 2 ** self.bpp - 1
+        self.maxc = 2 ** self.bpp - 1
         # data size per pixel band in the output RGB array
         self._set_dtype()
 
         # For scaling algorithms
-        hashsize = 65536
+        hashsize = self.t_.get('color_hashsize', 65536)
         if dist is None:
-            dist = ColorDist.LinearDist(hashsize)
+            color_alg_name = self.t_.get('color_algorithm', 'linear')
+            color_dist_class = ColorDist.get_dist(color_alg_name)
+            dist = color_dist_class(hashsize)
         self.dist = dist
 
-        self.reset_sarr(callback=False)
-
         # For callbacks
         for name in ('changed', ):
             self.enable_callback(name)
 
+        cm_name = self.t_.get('color_map', 'gray')
+        self.set_color_map(cm_name)
+
+        im_name = self.t_.get('intensity_map', 'ramp')
+        self.set_intensity_map(im_name)
+
+        # Initialize color array
+        carr = self.t_.get('color_array', None)
+        if carr is not None:
+            self.set_carr(carr)
+        else:
+            self.calc_cmap()
+
+        # Initialize shift array
+        sarr = self.t_.get('shift_array', None)
+        if sarr is not None:
+            self.set_sarr(sarr)
+        else:
+            self.reset_sarr(callback=False)
+
     def _set_dtype(self):
         if self.bpp <= 8:
             self.dtype = np.uint8
@@ -132,11 +178,21 @@ class RGBMapper(Callback.Callbacks):
         be 16, etc.
         """
         self.bpp = bpp
-        self.maxv = 2 ** self.bpp - 1
+        self.maxc = 2 ** self.bpp - 1
         self._set_dtype()
         self.calc_cmap()
         self.recalc(callback=False)
 
+    def get_settings(self):
+        return self.t_
+
+    def set_color_map(self, cmap_name):
+        self.t_.set(color_map=cmap_name)
+
+    def color_map_set_cb(self, setting, cmap_name):
+        cm = mod_cmap.get_cmap(cmap_name)
+        self.set_cmap(cm, callback=True)
+
     def set_cmap(self, cmap, callback=True):
         """
         Set the color map used by this RGBMapper.
@@ -146,7 +202,10 @@ class RGBMapper(Callback.Callbacks):
         """
         self.cmap = cmap
         self.calc_cmap()
-        self.recalc(callback=callback)
+        # TEMP: ignore passed callback parameter
+        # callback=False in the following because we don't want to
+        # recursively invoke set_cmap()
+        self.t_.set(color_map=cmap.name, callback=False)
 
     def get_cmap(self):
         """
@@ -156,23 +215,29 @@ class RGBMapper(Callback.Callbacks):
 
     def calc_cmap(self):
         clst = self.cmap.clst
-        arr = np.array(clst).transpose() * float(self.maxv)
-        # does this really need to be the same type as rgbmap output type?
-        self.carr = np.round(arr).astype(self.dtype, copy=False)
         self.maxc = len(clst) - 1
+        arr = np.array(clst).transpose() * float(self.maxc)
+        # does this really need to be the same type as rgbmap output type?
+        carr = np.round(arr).astype(self.dtype, copy=False)
+        self.t_.set(color_array=carr)
 
     def invert_cmap(self, callback=True):
-        self.carr = np.fliplr(self.carr)
-        self.recalc(callback=callback)
+        carr = np.fliplr(self.carr)
+        # TEMP: ignore passed callback parameter
+        self.t_.set(color_array=carr)
 
     def rotate_cmap(self, num, callback=True):
-        self.carr = np.roll(self.carr, num, axis=1)
-        self.recalc(callback=callback)
+        carr = np.roll(self.carr, num, axis=1)
+        # TEMP: ignore passed callback parameter
+        self.t_.set(color_array=carr)
 
     def restore_cmap(self, callback=True):
         self.reset_sarr(callback=False)
+        # TEMP: ignore passed callback parameter
         self.calc_cmap()
-        self.recalc(callback=callback)
+
+    def reset_cmap(self):
+        self.recalc()
 
     def get_rgb(self, index):
         """
@@ -183,7 +248,7 @@ class RGBMapper(Callback.Callbacks):
 
     def get_rgbval(self, index):
         """
-        Return a tuple of (R, G, B) values in the 0-maxv range associated
+        Return a tuple of (R, G, B) values in the 0-maxc range associated
         mapped by the value of `index`.
         """
         assert (index >= 0) and (index <= self.maxc), \
@@ -193,6 +258,13 @@ class RGBMapper(Callback.Callbacks):
                 self.arr[1][index],
                 self.arr[2][index])
 
+    def set_intensity_map(self, imap_name):
+        self.t_.set(intensity_map=imap_name)
+
+    def intensity_map_set_cb(self, setting, imap_name):
+        im = mod_imap.get_imap(imap_name)
+        self.set_imap(im, callback=True)
+
     def set_imap(self, imap, callback=True):
         """
         Set the intensity map used by this RGBMapper.
@@ -202,7 +274,11 @@ class RGBMapper(Callback.Callbacks):
         """
         self.imap = imap
         self.calc_imap()
-        self.recalc(callback=callback)
+        # TEMP: ignore passed callback parameter
+        self.recalc()
+        # callback=False in the following because we don't want to
+        # recursively invoke set_imap()
+        self.t_.set(intensity_map=imap.name, callback=False)
 
     def get_imap(self):
         """
@@ -216,24 +292,56 @@ class RGBMapper(Callback.Callbacks):
 
     def reset_sarr(self, callback=True):
         maxlen = self.maxc + 1
-        self.sarr = np.arange(maxlen)
         self.scale_pct = 1.0
-        if callback:
-            self.make_callback('changed')
-
-    def set_sarr(self, sarr, callback=True):
-        maxlen = self.maxc + 1
-        assert len(sarr) == maxlen, \
-            RGBMapError("shift map length %d != %d" % (len(sarr), maxlen))
-        self.sarr = sarr.astype(np.uint, copy=False)
-        self.scale_pct = 1.0
-
-        if callback:
-            self.make_callback('changed')
+        sarr = np.arange(maxlen)
+        # TEMP: ignore passed callback parameter
+        self.t_.set(shift_array=sarr)
 
     def get_sarr(self):
         return self.sarr
 
+    def set_sarr(self, sarr, callback=True):
+        if sarr is not None:
+            sarr = np.asarray(sarr, dtype=np.uint)
+        # TEMP: ignore passed callback parameter
+        self.t_.set(shift_array=sarr)
+
+    def shift_array_set_cb(self, setting, sarr):
+        if sarr is not None:
+            sarr = np.asarray(sarr)
+            maxlen = self.maxc + 1
+            _len = len(sarr)
+            if _len != maxlen:
+                raise RGBMapError("shift map length %d != %d" % (_len, maxlen))
+            self.sarr = sarr.astype(np.uint, copy=False)
+            # NOTE: can't reset scale_pct here because it results in a
+            # loop with e.g. scale_and_shift()
+            #self.scale_pct = 1.0
+            self.make_callback('changed')
+        else:
+            self.reset_sarr(callback=True)
+
+    def get_carr(self):
+        return self.carr
+
+    def set_carr(self, carr, callback=True):
+        if carr is not None:
+            carr = np.asarray(carr)
+        # TEMP: ignore passed callback parameter
+        self.t_.set(color_array=carr, callback=True)
+
+    def color_array_set_cb(self, setting, carr):
+        if carr is not None:
+            carr = np.asarray(carr)
+            maxlen = self.maxc + 1
+            self.carr = carr.astype(self.dtype, copy=False)
+            _len = carr.shape[1]
+            if _len != maxlen:
+                raise RGBMapError("color map length %d != %d" % (_len, maxlen))
+        else:
+            self.calc_cmap()
+        self.recalc(callback=True)
+
     def recalc(self, callback=True):
         self.arr = np.copy(self.carr)
         # Apply intensity map to rearrange colors
@@ -252,9 +360,12 @@ class RGBMapper(Callback.Callbacks):
         return self.dist.get_hash_size()
 
     def set_hash_size(self, size, callback=True):
+        # TEMP: ignore passed callback parameter
+        self.t_.set(color_hashsize=size)
+
+    def color_hashsize_set_cb(self, setting, size):
         self.dist.set_hash_size(size)
-        if callback:
-            self.make_callback('changed')
+        self.make_callback('changed')
 
     def get_hash_algorithms(self):
         return ColorDist.get_dist_names()
@@ -273,10 +384,14 @@ class RGBMapper(Callback.Callbacks):
         if callback:
             self.make_callback('changed')
 
-    def set_hash_algorithm(self, name, callback=True, **kwdargs):
-        hashsize = self.dist.get_hash_size()
-        dist = ColorDist.get_dist(name)(hashsize, **kwdargs)
-        self.set_dist(dist, callback=callback)
+    def set_hash_algorithm(self, name, callback=True, **kwargs):
+        # TODO: deal with algorithm parameters in kwargs
+        self.t_.set(color_algorithm=name)
+
+    def color_algorithm_set_cb(self, setting, name):
+        size = self.t_.get('color_hashsize', self.dist.get_hash_size())
+        dist = ColorDist.get_dist(name)(size)
+        self.set_dist(dist, callback=True)
 
     def get_order_indexes(self, order, cs):
         order = order.upper()
@@ -288,7 +403,7 @@ class RGBMapper(Callback.Callbacks):
         return [order.index(c) for c in cs]
 
     def _get_rgbarray(self, idx, rgbobj, image_order=''):
-        # NOTE: data is assumed to be in the range 0-maxv at this point
+        # NOTE: data is assumed to be in the range 0-maxc at this point
         # but clip as a precaution
         # See NOTE [A]: idx is always an array calculated in the caller and
         #    discarded afterwards
@@ -355,7 +470,7 @@ class RGBMapper(Callback.Callbacks):
         # set alpha channel
         if res.hasAlpha:
             aa = res.get_slice('A')
-            aa.fill(self.maxv)
+            aa.fill(self.maxc)
 
         idx = self.get_hasharray(idx)
 
@@ -385,7 +500,7 @@ class RGBMapper(Callback.Callbacks):
         xi = np.mgrid[0:new_wd]
         iscale_x = float(old_wd) / float(new_wd)
 
-        xi = (xi * iscale_x).astype('int', copy=False)
+        xi = (xi * iscale_x).astype(np.uint, copy=False)
         xi = xi.clip(0, old_wd - 1)
         newdata = sarr[xi]
         return newdata
@@ -395,9 +510,7 @@ class RGBMapper(Callback.Callbacks):
         maxlen = self.maxc + 1
         assert len(work) == maxlen, \
             RGBMapError("shifted shift map is != %d" % maxlen)
-        self.sarr = work
-        if callback:
-            self.make_callback('changed')
+        self.t_.set(shift_array=work)
 
     def scale_and_shift(self, scale_pct, shift_pct, callback=True):
         """Stretch and/or shrink the color map via altering the shift map.
@@ -433,9 +546,7 @@ class RGBMapper(Callback.Callbacks):
         assert len(work) == maxlen, \
             RGBMapError("shifted shift map is != %d" % maxlen)
 
-        self.sarr = work
-        if callback:
-            self.make_callback('changed')
+        self.t_.set(shift_array=work)
 
     def stretch(self, scale_factor, callback=True):
         """Stretch the color map via altering the shift map.
@@ -444,16 +555,12 @@ class RGBMapper(Callback.Callbacks):
         self.scale_and_shift(self.scale_pct, 0.0, callback=callback)
 
     def copy_attributes(self, dst_rgbmap):
-        dst_rgbmap.set_cmap(self.cmap, callback=False)
-        dst_rgbmap.set_imap(self.imap, callback=False)
-        dst_rgbmap.set_hash_algorithm(str(self.dist), callback=False)
-        # TODO: set hash size
-        dst_rgbmap.carr = np.copy(self.carr)
-        dst_rgbmap.sarr = np.copy(self.sarr)
-        dst_rgbmap.recalc()
+        self.t_.copy_settings(dst_rgbmap.get_settings(),
+                              keylist=self.settings_keys)
 
-    def reset_cmap(self):
-        self.recalc()
+    def share_attributes(self, dst_rgbmap):
+        self.t_.share_settings(dst_rgbmap.get_settings(),
+                               keylist=self.settings_keys)
 
 
 class NonColorMapper(RGBMapper):
@@ -466,12 +573,12 @@ class NonColorMapper(RGBMapper):
     def __init__(self, logger, dist=None, bpp=None):
         super(NonColorMapper, self).__init__(logger, dist=dist, bpp=bpp)
 
-        maxlen = self.maxv + 1
+        maxlen = self.maxc + 1
         self.dist.set_hash_size(maxlen)
         self.reset_sarr(callback=False)
 
     def _get_rgbarray(self, idx, rgbobj, image_order='RGB'):
-        # NOTE: data is assumed to be in the range 0-maxv at this point
+        # NOTE: data is assumed to be in the range 0-maxc at this point
         # but clip as a precaution
         # See NOTE [A]: idx is always an array calculated in the caller and
         #    discarded afterwards
@@ -503,16 +610,16 @@ class PassThruRGBMapper(RGBMapper):
         super(PassThruRGBMapper, self).__init__(logger, bpp=bpp)
 
         # ignore passed in distribution
-        maxlen = self.maxv + 1
+        maxlen = self.maxc + 1
         self.dist = ColorDist.LinearDist(maxlen)
 
     def get_hasharray(self, idx):
-        # data is already constrained to 0..maxv and we want to
+        # data is already constrained to 0..maxc and we want to
         # bypass color redistribution
         return idx
 
     def _get_rgbarray(self, idx, rgbobj, image_order='RGB'):
-        # NOTE: data is assumed to be in the range 0-maxv at this point
+        # NOTE: data is assumed to be in the range 0-maxc at this point
         # but clip as a precaution
         # See NOTE [A]: idx is always an array calculated in the caller and
         #    discarded afterwards
