@@ -4,21 +4,24 @@
 # This is open-source software licensed under a BSD license.
 # Please see the file LICENSE.txt for details.
 
+import numpy as np
+
 import cv2  # noqa
 from . import CvHelp
 
+from ginga.canvas import render
 # force registration of all canvas types
 import ginga.canvas.types.all  # noqa
 from ginga import trcalc
 
 
-class RenderContext(object):
+class RenderContext(render.RenderContextBase):
 
-    def __init__(self, viewer):
-        self.viewer = viewer
+    def __init__(self, renderer, viewer, surface):
+        render.RenderContextBase.__init__(self, renderer, viewer)
 
         # TODO: encapsulate this drawable
-        self.cr = CvHelp.CvContext(self.viewer.get_surface())
+        self.cr = CvHelp.CvContext(surface)
 
         self.pen = None
         self.brush = None
@@ -48,6 +51,7 @@ class RenderContext(object):
                 fontsize = shape.fontsize
             else:
                 fontsize = shape.scale_font(self.viewer)
+            fontsize = self.scale_fontsize(fontsize)
             alpha = getattr(shape, 'alpha', 1.0)
             self.font = self.cr.get_font(shape.font, fontsize, shape.color,
                                          alpha=alpha)
@@ -73,6 +77,7 @@ class RenderContext(object):
             self.brush = self.cr.get_brush(color, alpha=alpha)
 
     def set_font(self, fontname, fontsize, color='black', alpha=1.0):
+        fontsize = self.scale_fontsize(fontsize)
         self.font = self.cr.get_font(fontname, fontsize, color,
                                      alpha=alpha)
 
@@ -91,10 +96,6 @@ class RenderContext(object):
     def draw_circle(self, cx, cy, cradius):
         self.cr.circle((cx, cy), cradius, self.pen, self.brush)
 
-    def draw_ellipse(self, cx, cy, cxradius, cyradius, theta):
-        self.cr.ellipse((cx, cy), cxradius, cyradius, theta,
-                        self.pen, self.brush)
-
     def draw_line(self, cx1, cy1, cx2, cy2):
         self.cr.line((cx1, cy1), (cx2, cy2), self.pen)
 
@@ -103,13 +104,57 @@ class RenderContext(object):
         self.cr.path(cpoints, self.pen)
 
 
-class CanvasRenderer(object):
+class CanvasRenderer(render.RendererBase):
 
     def __init__(self, viewer):
-        self.viewer = viewer
+        render.RendererBase.__init__(self, viewer)
+
+        self.kind = 'opencv'
+        # According to OpenCV documentation:
+        # "If you are using your own image rendering and I/O functions,
+        # you can use any channel ordering. The drawing functions process
+        # each channel independently and do not depend on the channel
+        # order or even on the used color space."
+        self.rgb_order = 'RGB'
+        self.surface = None
+        self.dims = ()
+
+    def resize(self, dims):
+        """Resize our drawing area to encompass a space defined by the
+        given dimensions.
+        """
+        width, height = dims[:2]
+        self.dims = (width, height)
+        self.logger.debug("renderer reconfigured to %dx%d" % (
+            width, height))
+
+        # create cv surface the size of the window
+        # (cv just uses numpy arrays!)
+        depth = len(self.rgb_order)
+        self.surface = np.zeros((height, width, depth), dtype=np.uint8)
+
+    def render_image(self, rgbobj, dst_x, dst_y):
+        """Render the image represented by (rgbobj) at dst_x, dst_y
+        in the pixel space.
+        """
+        if self.surface is None:
+            return
+        self.logger.debug("redraw surface")
+
+        # get window contents as an array and store it into the CV surface
+        rgb_arr = self.viewer.getwin_array(order=self.rgb_order, dtype=np.uint8)
+        # TODO: is there a faster way to copy this array in?
+        self.surface[:, :, :] = rgb_arr
+
+    def get_surface_as_array(self, order=None):
+        if self.surface is None:
+            raise render.RenderError("No OpenCv surface defined")
+
+        # adjust according to viewer's needed order
+        return self.reorder(order, self.surface)
 
     def setup_cr(self, shape):
-        cr = RenderContext(self.viewer)
+        cr = RenderContext(self, self.viewer, self.surface)
         cr.initialize_from_shape(shape, font=False)
         return cr
 
