@@ -12,6 +12,7 @@ import sys
 import ginga.toolkit as ginga_toolkit
 from ginga import AstroImage, colors
 from ginga.canvas.CanvasObject import get_canvas_types
+from ginga.canvas import render
 from ginga.misc import log
 
 
@@ -292,6 +293,10 @@ def main(options, args):
 
     viewer = FitsViewer(logger)
 
+    if options.renderer is not None:
+        render_class = render.get_render_class(options.renderer)
+        viewer.fitsimage.set_renderer(render_class(viewer.fitsimage))
+
     viewer.top.resize(700, 540)
 
     if len(args) > 0:
@@ -333,6 +338,9 @@ if __name__ == "__main__":
     optprs.add_option("--profile", dest="profile", action="store_true",
                       default=False,
                       help="Run the profiler on main()")
+    optprs.add_option("-r", "--renderer", dest="renderer", metavar="NAME",
+                      default=None,
+                      help="Choose renderer (pil|agg|opencv|cairo|qt)")
     log.addlogopts(optprs)
 
     (options, args) = optprs.parse_args(sys.argv[1:])
