@@ -7,6 +7,7 @@
 import sys
 import os.path
 import math
+import random
 
 from ginga.misc import Bunch, Callback
 from ginga.fonts import font_asst
@@ -373,10 +374,22 @@ class MDIWidget(Gtk.Layout):
         subwin.add_callback('maximize', lambda *args: self.maximize_page(subwin))
         subwin.add_callback('minimize', lambda *args: self.minimize_page(subwin))
 
-        self.put(subwin.frame, self.cascade_offset, self.cascade_offset)
+        # pick a random spot to place the window initially
+        rect = self.get_allocation()
+        wd, ht = rect.width, rect.height
+        x = random.randint(self.cascade_offset,
+                           max(self.cascade_offset + 10, wd // 2))
+        y = random.randint(self.cascade_offset,
+                           max(self.cascade_offset + 10, ht // 2))
 
-        self.update_subwin_position(subwin)
-        self.update_subwin_size(subwin)
+        self.put(subwin.frame, x, y)
+
+        # note: seem to need a slight delay to let the widget be mapped
+        # in order to accurately determine its position and size
+        #self.update_subwin_position(subwin)
+        #self.update_subwin_size(subwin)
+        GObject.timeout_add(1000, self.update_subwin_position, subwin)
+        GObject.timeout_add(1500, self.update_subwin_size, subwin)
 
         self._update_area_size()
         return subwin
@@ -956,11 +969,15 @@ def set_default_style():
     with open(gtk_css, 'rb') as css_f:
         css_data = css_f.read()
 
-    style_provider.load_from_data(css_data)
+    try:
+        style_provider.load_from_data(css_data)
 
-    Gtk.StyleContext.add_provider_for_screen(
-        Gdk.Screen.get_default(), style_provider,
-        Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION
-    )
+        Gtk.StyleContext.add_provider_for_screen(
+            Gdk.Screen.get_default(), style_provider,
+            Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION
+        )
+
+    except Exception:
+        pass
 
 # END
