@@ -117,7 +117,9 @@ class WidgetBase(Callback.Callbacks):
 
     def resize(self, width, height):
         self.widget.set_size_request(width, height)
+
         # hackish way to allow the widget to be resized down again later
+        # NOTE: this causes some problems for sizing certain widgets
         # GObject.idle_add(self.widget.set_size_request, -1, -1)
 
     def get_font(self, font_family, point_size):
@@ -2044,6 +2046,9 @@ class Application(Callback.Callbacks):
     def mainloop(self):
         Gtk.main()
 
+    def quit(self):
+        Gtk.main_quit()
+
 
 class Dialog(TopLevelMixin, WidgetBase):
 
