@@ -339,9 +339,6 @@ class MDIWidget(gtk.Layout):
         self.minimized_width = 150
         self.delta_px = 50
 
-        self.connect("motion_notify_event", self.motion_notify_event)
-        self.connect("button_press_event", self.button_press_event)
-        self.connect("button_release_event", self.button_release_event)
         mask = self.get_events()
         self.set_events(mask |
                         gtk.gdk.ENTER_NOTIFY_MASK |
@@ -356,6 +353,10 @@ class MDIWidget(gtk.Layout):
                         gtk.gdk.POINTER_MOTION_HINT_MASK |
                         gtk.gdk.SCROLL_MASK)
 
+        self.connect("motion_notify_event", self.motion_notify_event)
+        self.connect("button_press_event", self.button_press_event)
+        self.connect("button_release_event", self.button_release_event)
+
         self.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse("gray50"))
 
     def append_page(self, widget, label):
@@ -373,6 +374,7 @@ class MDIWidget(gtk.Layout):
         self.update_subwin_position(subwin)
         self.update_subwin_size(subwin)
 
+        self._update_area_size()
         return subwin
 
     def set_tab_reorderable(self, w, tf):
@@ -424,6 +426,7 @@ class MDIWidget(gtk.Layout):
             frame = subwin.frame
             super(MDIWidget, self).remove(frame)
             widget.unparent()
+        self._update_area_size()
 
     def get_widget_position(self, widget):
         x, y, width, height = widget.get_allocation()
@@ -526,6 +529,16 @@ class MDIWidget(gtk.Layout):
             button |= 0x1 << (event.button - 1)
         return True
 
+    def _update_area_size(self):
+        x, y, mx_wd, mx_ht = self.get_allocation()
+
+        for subwin in self.children:
+            x, y, wd, ht = subwin.frame.get_allocation()
+
+            mx_wd, mx_ht = max(mx_wd, x + wd), max(mx_ht, y + ht)
+
+        self.set_size(mx_wd, mx_ht)
+
     def _resize(self, bnch, x_root, y_root):
         subwin = bnch.subwin
         updates = bnch.updates
@@ -563,6 +576,8 @@ class MDIWidget(gtk.Layout):
             # this works better if it is not self.resize_page()
             subwin.frame.set_size_request(wd, ht)
 
+        self._update_area_size()
+
     def button_release_event(self, widget, event):
         x_root, y_root = event.x_root, event.y_root
         button = self.kbdmouse_mask
@@ -588,6 +603,8 @@ class MDIWidget(gtk.Layout):
                 self.resize_page(subwin, subwin.width, subwin.height)
 
             self.selected_child = None
+
+        self._update_area_size()
         return True
 
     def motion_notify_event(self, widget, event):
@@ -613,6 +630,7 @@ class MDIWidget(gtk.Layout):
             elif bnch.action == 'resize':
                 self._resize(bnch, x_root, y_root)
 
+        self._update_area_size()
         return True
 
     def tile_pages(self):
@@ -642,6 +660,8 @@ class MDIWidget(gtk.Layout):
 
                     self.raise_widget(subwin)
 
+        self._update_area_size()
+
     def cascade_pages(self):
         x, y = 0, 0
         for subwin in self.children:
@@ -650,6 +670,8 @@ class MDIWidget(gtk.Layout):
             x += self.cascade_offset
             y += self.cascade_offset
 
+        self._update_area_size()
+
     def use_tabs(self, tf):
         pass
 
@@ -668,6 +690,8 @@ class MDIWidget(gtk.Layout):
         self.resize_page(subwin, wd, ht)
         self.move_page(subwin, 0, 0)
 
+        self._update_area_size()
+
     def minimize_page(self, subwin):
         rect = self.get_allocation()
         height = rect.height
@@ -682,8 +706,10 @@ class MDIWidget(gtk.Layout):
         self.move_page(subwin, x, height - ht)
         #self.lower_widget(subwin)
 
+        self._update_area_size()
+
     def close_page(self, subwin):
-        pass
+        self._update_area_size()
 
 
 class FileSelection(object):
