@@ -282,8 +282,7 @@ class Desktop(Callback.Callbacks):
 
         def process_common_params(kind, widget, params):
             subst_params = Bunch.Bunch(name=None, height=-1, width=-1,
-                                       xpos=-1, ypos=-1, spacing=None,
-                                       wexp=None, hexp=None)
+                                       xpos=-1, ypos=-1, spacing=None)
             subst_params.update(params)
             params.update(subst_params)
 
@@ -298,8 +297,6 @@ class Desktop(Callback.Callbacks):
                                name=name, params=params)
             self.node[name] = bnch
 
-            wexp, hexp = params.wexp, params.hexp
-
             # User is specifying the size of the widget
             if isinstance(widget, Widgets.WidgetBase):
 
@@ -310,32 +307,18 @@ class Desktop(Callback.Callbacks):
                 if (params.width >= 0) or (params.height >= 0):
                     if params.width < 0:
                         width = widget.get_size()[0]
-                        if wexp is None:
-                            wexp = 8
                     else:
                         width = params.width
-                        if wexp is None:
-                            wexp = 1 | 4
                     if params.height < 0:
                         height = widget.get_size()[1]
-                        if hexp is None:
-                            hexp = 8
                     else:
                         height = params.height
-                        if hexp is None:
-                            hexp = 1 | 4
                     widget.resize(width, height)
 
-                # specify expansion policy of widget
-                if (wexp is not None) or (hexp is not None):
-                    if wexp is None:
-                        wexp = 0
-                    if hexp is None:
-                        hexp = 0
-
                 # User wants to place window somewhere
-                if params.xpos >= 0:
-                    widget.move(params.xpos, params.ypos)
+                if kind in ['top', 'dialog']:
+                    if params.xpos >= 0:
+                        widget.move(params.xpos, params.ypos)
 
             return bnch
 
@@ -516,11 +499,66 @@ class Desktop(Callback.Callbacks):
             pack(widget)
             return ['vbox', params] + res
 
+        # top-level dialog box
+        def dialog(params, rows, pack):
+            if len(self.toplevels) == 0:
+                raise ValueError("Need a top-level window to parent a dialog")
+
+            # any old top-level will do, for now...
+            top_w = self.toplevels[0]
+            widget = Widgets.Dialog(parent=top_w)
+            container = widget.get_content_area()
+
+            res = []
+            for dct in rows:
+                if isinstance(dct, dict):
+                    stretch = dct.get('stretch', 1)
+                    row = dct.get('row', None)
+                else:
+                    # assume a list defining the row
+                    stretch = 1
+                    row = dct
+                if row is not None:
+                    r = make(row,
+                             lambda w: container.add_widget(w,
+                                                            stretch=stretch))
+                    r = dict(row=r, stretch=stretch)
+                    res.append(r)
+
+            process_common_params('dialog', widget, params)
+
+            widget.show()
+            return ['dialog', params] + res
+
+        # top-level window
+        def toplevel(params, rows, pack):
+            widget = self.app.make_window()
+            self.toplevels.append(widget)
+
+            if len(rows) != 1:
+                raise ValueError("top-level windows can only have 1 child")
+
+            res = []
+            dct = rows[0]
+            if isinstance(dct, dict):
+                row = dct.get('row', None)
+            else:
+                # assume a list defining the row
+                row = dct
+            if row is not None:
+                r = make(row, lambda w: widget.set_widget(w))
+                r = dict(row=r)
+                res.append(r)
+
+            process_common_params('top', widget, params)
+
+            widget.show()
+            return ['top', params] + res
+
         # Sequence of separate top-level items
         def seq(params, cols, pack):
             def mypack(w):
                 w_top = self.app.make_window()
-                # w_top.cfg_expand(8, 8)
                 # Ask the size of the widget that wants to get packed
                 # and resize the top-level to fit
                 wd, ht = w.get_size()
@@ -533,15 +571,15 @@ class Desktop(Callback.Callbacks):
             res = []
             for dct in cols:
                 if isinstance(dct, dict):
-                    stretch = dct.get('stretch', 0)  # noqa
                     col = dct.get('col', None)
                 else:
                     # assume a list defining the col
-                    stretch = 0  # noqa
                     col = dct
                 if col is not None:
                     res.append(make(col, mypack))
 
+            # presumably, the passed-in pack is a no-op, so this
+            # should do nothing
             widget = Widgets.Label("Placeholder")
             pack(widget)
             return ['seq', params] + res
@@ -562,6 +600,10 @@ class Desktop(Callback.Callbacks):
                 res = vbox(params, rest, pack)
             elif kind == 'hbox':
                 res = hbox(params, rest, pack)
+            elif kind == 'dialog':
+                res = dialog(params, rest, pack)
+            elif kind == 'top':
+                res = toplevel(params, rest, pack)
             elif kind == 'seq':
                 res = seq(params, rest, pack)
             elif kind in ('ws', 'mdi', 'widget'):
