@@ -5,15 +5,15 @@ from ginga import toolkit
 tkname = toolkit.get_family()
 
 if tkname == 'qt':
-    from ginga.qtw.QtHelp import *
+    from ginga.qtw.QtHelp import *  # noqa
 
 elif tkname == 'gtk':
-    from ginga.gtkw.GtkHelp import *
+    from ginga.gtkw.GtkHelp import *  # noqa
 
 elif tkname == 'gtk3':
-    from ginga.gtk3w.GtkHelp import *
+    from ginga.gtk3w.GtkHelp import *  # noqa
 
 elif tkname == 'pg':
-    from ginga.web.pgw.PgHelp import *
+    from ginga.web.pgw.PgHelp import *  # noqa
 
-#END
+# END
