@@ -5,6 +5,7 @@
 # Please see the file LICENSE.txt for details.
 #
 import os
+import numpy as np
 
 from ginga import ImageView, Mixins, Bindings
 from ginga.util.io_rgb import RGBFileHandler
@@ -81,7 +82,7 @@ class ImageViewMock(ImageView.ImageViewBase):
         self.logger.debug("drawing to pixmap")
 
         # Prepare array for rendering
-        arr = rgbobj.get_array(self.rgb_order)
+        arr = rgbobj.get_array(self.rgb_order, dtype=np.uint8)
         (height, width) = arr.shape[:2]
 
         return self._render_offscreen(self.pixmap, arr, dst_x, dst_y,
@@ -105,12 +106,12 @@ class ImageViewMock(ImageView.ImageViewBase):
         self.configure(width, height)
 
     def get_image_as_array(self):
-        return self.getwin_array(order=self.rgb_order)
+        return self.getwin_array(order=self.rgb_order, dtype=np.uint8)
 
     def get_rgb_image_as_buffer(self, output=None, format='png',
                                 quality=90):
         # copy pixmap to buffer
-        data_np = self.getwin_array(order=self.rgb_order)
+        data_np = self.getwin_array(order=self.rgb_order, dtype=np.uint8)
         header = {}
         fmt_buf = self.rgb_fh.get_buffer(data_np, header, format,
                                          output=output)
@@ -204,6 +205,10 @@ class ImageViewMock(ImageView.ImageViewBase):
             # `delay` sec
             pass
 
+    def take_focus(self):
+        # have the widget grab the keyboard focus
+        pass
+
 
 class ImageViewEvent(ImageViewMock):
 
@@ -217,9 +222,6 @@ class ImageViewEvent(ImageViewMock):
         # gestures
         #...
 
-        # Does widget accept focus when mouse enters window
-        self.enter_focus = self.t_.get('enter_focus', True)
-
         # Define cursors
         for curname, filename in (('pan', 'openHandCursor.png'),
                                   ('pick', 'thinCrossCursor.png')):
@@ -270,9 +272,6 @@ class ImageViewEvent(ImageViewMock):
     def get_keyTable(self):
         return self._keytbl
 
-    def set_enter_focus(self, tf):
-        self.enter_focus = tf
-
     def map_event(self, widget, event):
         """
         Called when the window is mapped to the screen.
@@ -293,7 +292,8 @@ class ImageViewEvent(ImageViewMock):
         Called when the mouse cursor enters the window.
         Adjust method signature as appropriate for callback.
         """
-        if self.enter_focus:
+        enter_focus = self.t_.get('enter_focus', False)
+        if enter_focus:
             # set focus on widget
             pass
         return self.make_callback('enter')
