@@ -434,7 +434,9 @@ class SpinBox(WidgetBase):
         self.widget.setValue(val)
 
     def set_decimals(self, num):
-        self.widget.setDecimals(num)
+        if hasattr(self.widget, 'setDecimals'):
+            # only for QDoubleSpinBox
+            self.widget.setDecimals(num)
 
     def set_limits(self, minval, maxval, incr_value=1):
         adj = self.widget
@@ -640,6 +642,22 @@ class StatusBar(WidgetBase):
         self.widget.showMessage(msg_str, int(duration * 1000))
 
 
+class TreeWidgetItem(QtGui.QTreeWidgetItem):
+    """A hack to subclass QTreeWidgetItem to enable sorting by numbers
+    in a field.
+    """
+    def __init__(self, *args, **kwargs):
+        QtGui.QTreeWidgetItem.__init__(self, *args, **kwargs)
+
+    def __lt__(self, otherItem):
+        column = self.treeWidget().sortColumn()
+        try:
+            return float(self.text(column)) < float(otherItem.text(column))
+
+        except ValueError:
+            return self.text(column) < otherItem.text(column)
+
+
 class TreeView(WidgetBase):
     def __init__(self, auto_expand=False, sortable=False,
                  selection='single', use_alt_row_color=False,
@@ -736,7 +754,7 @@ class TreeView(WidgetBase):
 
             except KeyError:
                 # new item
-                item = QtGui.QTreeWidgetItem(parent_item, values)
+                item = TreeWidgetItem(parent_item, values)
                 if level == 1:
                     parent_item.addTopLevelItem(item)
                 else:
@@ -762,7 +780,7 @@ class TreeView(WidgetBase):
 
             except KeyError:
                 # new node
-                item = QtGui.QTreeWidgetItem(parent_item, [str(key)])
+                item = TreeWidgetItem(parent_item, [str(key)])
                 if level == 1:
                     parent_item.addTopLevelItem(item)
                 else:
@@ -1553,6 +1571,8 @@ class Toolbar(ContainerBase):
             iconw = QIcon(pixmap)
             action = self.widget.addAction(iconw, text,
                                            child._cb_redirect)
+            if text is not None and len(text) > 0:
+                self.widget.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         else:
             action = self.widget.addAction(text, child._cb_redirect)
         action.setCheckable(toggle)
@@ -1563,6 +1583,10 @@ class Toolbar(ContainerBase):
     def add_widget(self, child):
         self.add_ref(child)
         w = child.get_widget()
+        # in toolbars, generally don't want widgets to take up any more
+        # space than necessary
+        w.setSizePolicy(QtGui.QSizePolicy.Fixed,
+                        QtGui.QSizePolicy.Fixed)
         self.widget.addWidget(w)
         self.make_callback('widget-added', child)
 
@@ -1659,6 +1683,8 @@ class Menubar(ContainerBase):
         super(Menubar, self).__init__()
 
         self.widget = QtGui.QMenuBar()
+        if hasattr(self.widget, 'setNativeMenuBar'):
+            self.widget.setNativeMenuBar(False)
         self.menus = Bunch.Bunch(caseless=True)
 
     def add_widget(self, child, name):
