@@ -26,6 +26,7 @@ from ginga.misc import Bunch, Timer, Future
 from ginga.util import catalog, iohelper, io_fits, toolbox
 from ginga.canvas.CanvasObject import drawCatalog
 from ginga.canvas.types.layer import DrawingCanvas
+from ginga.canvas import render
 from ginga.util.six.moves import map
 
 # GUI imports
@@ -281,6 +282,36 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         opmon = channel.opmon
         opmon.deactivate(opname)
 
+    def call_local_plugin_method(self, chname, plugin_name, method_name,
+                                 args, kwargs):
+        """
+        Parameters
+        ----------
+        chname : str
+            The name of the channel containing the plugin.
+
+        plugin_name : str
+            The name of the local plugin containing the method to call.
+
+        method_name : str
+            The name of the method to call.
+
+        args : list or tuple
+            The positional arguments to the method
+
+        kwargs : dict
+            The keyword arguments to the method
+
+        Returns
+        -------
+        result : return value from calling the method
+        """
+        channel = self.get_channel(chname)
+        opmon = channel.opmon
+        p_obj = opmon.get_plugin(plugin_name)
+        method = getattr(p_obj, method_name)
+        return self.gui_call(method, *args, **kwargs)
+
     def start_global_plugin(self, plugin_name, raise_tab=False):
         self.gpmon.start_plugin_future(None, plugin_name, None)
         if raise_tab:
@@ -290,6 +321,31 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
     def stop_global_plugin(self, plugin_name):
         self.gpmon.deactivate(plugin_name)
 
+    def call_global_plugin_method(self, plugin_name, method_name,
+                                  args, kwargs):
+        """
+        Parameters
+        ----------
+        plugin_name : str
+            The name of the global plugin containing the method to call.
+
+        method_name : str
+            The name of the method to call.
+
+        args : list or tuple
+            The positional arguments to the method
+
+        kwargs : dict
+            The keyword arguments to the method
+
+        Returns
+        -------
+        result : return value from calling the method
+        """
+        p_obj = self.gpmon.get_plugin(plugin_name)
+        method = getattr(p_obj, method_name)
+        return self.gui_call(method, *args, **kwargs)
+
     def start_plugin(self, plugin_name, spec):
         ptype = spec.get('ptype', 'local')
         if ptype == 'local':
@@ -874,10 +930,24 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         self.next_channel_ws(ws)
 
     def add_channel_auto_ws(self, ws):
-        chpfx = self.settings.get('channel_prefix', "Image")
-        chpfx = ws.extdata.get('chpfx', chpfx)
+        chname = ws.extdata.w_chname.get_text().strip()
+        if len(chname) == 0:
+            # make up a channel name
+            chpfx = self.settings.get('channel_prefix', "Image")
+            chpfx = ws.extdata.get('chpfx', chpfx)
+            chname = self.make_channel_name(chpfx)
+
+        try:
+            self.get_channel(chname)
+            # <-- channel name already in use
+            self.show_error(
+                "Channel name '%s' cannot be used, sorry." % (chname),
+                raisetab=True)
+            return
+
+        except KeyError:
+            pass
 
-        chname = self.make_channel_name(chpfx)
         return self.add_channel(chname, workspace=ws.name)
 
     def add_channel_auto(self):
@@ -905,6 +975,9 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
 
     def add_workspace(self, wsname, wstype, inSpace='channels'):
 
+        if wsname in self.ds.get_tabnames(None):
+            raise ValueError("Tab name already in use: '%s'" % (wsname))
+
         ws = self.ds.make_ws(name=wsname, group=1, wstype=wstype,
                              use_toolbar=True)
         if inSpace != 'top level':
@@ -1022,7 +1095,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         for key in opmon.get_active():
             obj = opmon.get_plugin(key)
             try:
-                self.gui_do(obj.close)
+                self.gui_call(obj.close)
 
             except Exception as e:
                 self.logger.error(
@@ -1172,6 +1245,9 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
             if self.has_channel(chname):
                 return self.get_channel(chname)
 
+            if chname in self.ds.get_tabnames(None):
+                raise ValueError("Tab name already in use: '%s'" % (chname))
+
             name = chname
             if settings is None:
                 settings = self.prefs.create_category('channel_' + name)
@@ -1295,10 +1371,8 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
 
     def scale2text(self, scalefactor):
         if scalefactor >= 1.0:
-            #text = '%dx' % (int(scalefactor))
             text = '%.2fx' % (scalefactor)
         else:
-            #text = '1/%dx' % (int(1.0/scalefactor))
             text = '1/%.2fx' % (1.0 / scalefactor)
         return text
 
@@ -1309,11 +1383,12 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         channel = self.get_channel(chname)
         viewer = channel.viewer
         viewer.enable_autocuts('off')
-        viewer.enable_autozoom('on')
+        viewer.enable_autozoom('off')
+        viewer.enable_autocenter('on')
         viewer.cut_levels(0, 255)
 
-        #self.nongui_do(self.load_file, bannerFile, chname=chname)
         image = self.load_file(banner_file, chname=chname, wait=False)
+        viewer.scale_to(1, 1)
 
         # Insert Ginga version info
         header = image.get_header()
@@ -1321,7 +1396,6 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
 
         if raiseTab:
             self.change_channel(chname)
-            viewer.zoom_fit()
 
     def remove_image_by_name(self, chname, imname, impath=None):
         channel = self.get_channel(chname)
@@ -1696,6 +1770,12 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
                                      bindings=bd)
         fi.set_desired_size(size[0], size[1])
 
+        # Custom renderer set in channel settings?
+        r_name = settings.get('renderer', None)
+        if r_name is not None:
+            render_class = render.get_render_class(r_name)
+            fi.set_renderer(render_class(fi))
+
         canvas = DrawingCanvas()
         canvas.enable_draw(False)
         fi.set_canvas(canvas)
@@ -1710,13 +1790,13 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         if focus_ind is None:
             focus_ind = self.settings.get('show_focus_indicator', False)
         fi.show_focus_indicator(focus_ind)
-        fi.enable_auto_orient(True)
+        fi.use_image_profile = True
 
         fi.add_callback('cursor-changed', self.motion_cb)
         fi.add_callback('cursor-down', self.force_focus_cb)
         fi.add_callback('key-down-none', self.keypress)
         fi.add_callback('drag-drop', self.dragdrop)
-        fi.ui_setActive(True)
+        fi.ui_set_active(True)
 
         bd = fi.get_bindings()
         bd.enable_all(True)
@@ -1919,8 +1999,8 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         #b.share_settings.set_length(60)
 
         cbox = b.workspace_type
-        cbox.append_text("Grid")
         cbox.append_text("Tabs")
+        cbox.append_text("Grid")
         cbox.append_text("MDI")
         cbox.append_text("Stack")
         cbox.set_index(0)
@@ -1939,7 +2019,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         b.channel_prefix.set_text(chpfx)
         spnbtn = b.num_channels
         spnbtn.set_limits(0, 36, incr_value=1)
-        spnbtn.set_value(4)
+        spnbtn.set_value(0)
 
         dialog = Widgets.Dialog(title="Add Workspace",
                                 flags=0,
@@ -2076,7 +2156,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
             self.show_error("Channel name already in use: '%s'" % (chname))
             return True
 
-        self.add_channel(chname, workspace=wsname)
+        self.error_wrap(self.add_channel, chname, workspace=wsname)
         return True
 
     def add_channels_cb(self, w, rsp, b, names):
@@ -2090,7 +2170,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
 
         for i in range(num):
             chname = self.make_channel_name(chpfx)
-            self.add_channel(chname, workspace=wsname)
+            self.error_wrap(self.add_channel, chname, workspace=wsname)
         return True
 
     def delete_channel_cb(self, w, rsp, chname):
@@ -2140,6 +2220,12 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
 
             tb.add_separator()
 
+            entry = Widgets.TextEntry()
+            entry.set_length(8)
+            entry.set_tooltip("Name for a new channel")
+            ws.extdata.w_chname = entry
+            btn = tb.add_widget(entry)
+
             # add toolbar buttons adding and deleting channels
             iconpath = os.path.join(self.iconpath, "inbox_plus_48.png")
             btn = tb.add_action(None, iconpath=iconpath, iconsize=(24, 23))
@@ -2166,7 +2252,8 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
             try:
                 nb = self.ds.get_nb(wsname)  # noqa
                 self.show_error(
-                    "Workspace name '%s' cannot be used, sorry." % (wsname))
+                    "Workspace name '%s' cannot be used, sorry." % (wsname),
+                    raisetab=True)
                 self.ds.remove_dialog(w)
                 return
 
