@@ -622,7 +622,7 @@ def calc_image_merge_clip(p1, p2, dst, q1, q2):
 
 def overlay_image_2d(dstarr, pos, srcarr, dst_order='RGBA',
                      src_order='RGBA',
-                     alpha=1.0, copy=False, fill=True, flipy=False):
+                     alpha=1.0, copy=False, fill=False, flipy=False):
 
     dst_ht, dst_wd, dst_ch = dstarr.shape
     dst_type = dstarr.dtype
@@ -697,17 +697,23 @@ def overlay_image_2d(dstarr, pos, srcarr, dst_order='RGBA',
     if get_order != src_order:
         srcarr = reorder_image(get_order, srcarr, src_order)
 
-    # calculate alpha blending
-    #   Co = CaAa + CbAb(1 - Aa)
-    a_arr = (alpha * srcarr[0:src_ht, 0:src_wd, slc]).astype(dst_type, copy=False)
-    b_arr = ((1.0 - alpha) * dstarr[dst_y:dst_y + src_ht,
-                                    dst_x:dst_x + src_wd,
-                                    slc]).astype(dst_type, copy=False)
+    if np.isscalar(alpha) and alpha == 1.0:
+        # optimization to avoid alpha blending
+        # Place our srcarr into this dstarr at dst offsets
+        dstarr[dst_y:dst_y + src_ht, dst_x:dst_x + src_wd, slc] = (
+            srcarr[0:src_ht, 0:src_wd, slc])
+    else:
+        # calculate alpha blending
+        #   Co = CaAa + CbAb(1 - Aa)
+        a_arr = (alpha * srcarr[0:src_ht, 0:src_wd, slc]).astype(dst_type,
+                                                                 copy=False)
+        b_arr = ((1.0 - alpha) * dstarr[dst_y:dst_y + src_ht,
+                                        dst_x:dst_x + src_wd,
+                                        slc]).astype(dst_type, copy=False)
 
-    # Place our srcarr into this dstarr at dst offsets
-    #dstarr[dst_y:dst_y+src_ht, dst_x:dst_x+src_wd, slc] += addarr[0:src_ht, 0:src_wd, slc]
-    dstarr[dst_y:dst_y + src_ht, dst_x:dst_x + src_wd, slc] = \
-        a_arr[0:src_ht, 0:src_wd, slc] + b_arr[0:src_ht, 0:src_wd, slc]
+        # Place our srcarr into this dstarr at dst offsets
+        dstarr[dst_y:dst_y + src_ht, dst_x:dst_x + src_wd, slc] = (
+            a_arr[0:src_ht, 0:src_wd, slc] + b_arr[0:src_ht, 0:src_wd, slc])
 
     return dstarr
 
@@ -794,7 +800,6 @@ def overlay_image_3d(dstarr, pos, srcarr, dst_order='RGBA', src_order='RGBA',
         # if overlay source contains an alpha channel, extract it
         # and use it, otherwise use scalar keyword parameter
         alpha = srcarr[0:src_ht, 0:src_wd, 0:src_dp, sa_idx] / float(src_max_val)
-        #alpha = np.dstack((alpha, alpha, alpha))
         alpha = np.concatenate([alpha[..., np.newaxis],
                                 alpha[..., np.newaxis],
                                 alpha[..., np.newaxis]],
@@ -807,20 +812,27 @@ def overlay_image_3d(dstarr, pos, srcarr, dst_order='RGBA', src_order='RGBA',
     if get_order != src_order:
         srcarr = reorder_image(get_order, srcarr, src_order)
 
-    # calculate alpha blending
-    #   Co = CaAa + CbAb(1 - Aa)
-    a_arr = (alpha * srcarr[0:src_ht, 0:src_wd,
-                            0:src_dp, slc]).astype(dst_type, copy=False)
-    b_arr = ((1.0 - alpha) * dstarr[dst_y:dst_y + src_ht,
-                                    dst_x:dst_x + src_wd,
-                                    dst_z:dst_z + src_dp,
-                                    slc]).astype(dst_type, copy=False)
+    if np.isscalar(alpha) and alpha == 1.0:
+        # optimization to avoid alpha blending
+        # Place our srcarr into this dstarr at dst offsets
+        dstarr[dst_y:dst_y + src_ht, dst_x:dst_x + src_wd,
+               dst_z:dst_z + src_dp, slc] = (
+            srcarr[0:src_ht, 0:src_wd, 0:src_dp, slc])
+    else:
+        # calculate alpha blending
+        #   Co = CaAa + CbAb(1 - Aa)
+        a_arr = (alpha * srcarr[0:src_ht, 0:src_wd,
+                                0:src_dp, slc]).astype(dst_type, copy=False)
+        b_arr = ((1.0 - alpha) * dstarr[dst_y:dst_y + src_ht,
+                                        dst_x:dst_x + src_wd,
+                                        dst_z:dst_z + src_dp,
+                                        slc]).astype(dst_type, copy=False)
 
-    # Place our srcarr into this dstarr at dst offsets
-    dstarr[dst_y:dst_y + src_ht, dst_x:dst_x + src_wd,
-           dst_z:dst_z + src_dp, slc] = \
-        a_arr[0:src_ht, 0:src_wd, 0:src_dp, slc] + \
-        b_arr[0:src_ht, 0:src_wd, 0:src_dp, slc]
+        # Place our srcarr into this dstarr at dst offsets
+        dstarr[dst_y:dst_y + src_ht, dst_x:dst_x + src_wd,
+               dst_z:dst_z + src_dp, slc] = (
+            a_arr[0:src_ht, 0:src_wd, 0:src_dp, slc] +
+            b_arr[0:src_ht, 0:src_wd, 0:src_dp, slc])
 
     return dstarr
 
@@ -834,10 +846,34 @@ def overlay_image(dstarr, pos, srcarr, **kwargs):
 
 
 def reorder_image(dst_order, src_arr, src_order):
-    indexes = [src_order.index(c) for c in dst_order]
-    #return np.dstack([ src_arr[..., idx] for idx in indexes ])
-    return np.concatenate([src_arr[..., idx, np.newaxis]
-                           for idx in indexes], axis=-1)
+    """Reorder src_arr, with order of color planes in src_order, as
+    dst_order.
+    """
+    depth = src_arr.shape[2]
+    if depth != len(src_order):
+        raise ValueError("src_order (%s) does not match array depth (%d)" % (
+            src_order, depth))
+
+    bands = []
+    if dst_order == src_order:
+        return np.ascontiguousarray(src_arr)
+
+    elif 'A' not in dst_order or 'A' in src_order:
+        # <-- we don't have to add an alpha plane, just create a new view
+        idx = np.array([src_order.index(c) for c in dst_order])
+        return np.ascontiguousarray(src_arr[..., idx])
+
+    else:
+        # <-- dst order requires missing alpha channel
+        indexes = [src_order.index(c) for c in dst_order.replace('A', '')]
+        bands = [src_arr[..., idx, np.newaxis] for idx in indexes]
+        ht, wd = src_arr.shape[:2]
+        dst_type = src_arr.dtype
+        dst_max_val = np.iinfo(dst_type).max
+        alpha = np.full((ht, wd, 1), dst_max_val, dtype=dst_type)
+        bands.insert(dst_order.index('A'), alpha)
+
+    return np.concatenate(bands, axis=-1)
 
 
 def strip_z(pts):
@@ -868,4 +904,46 @@ def get_bounds(pts):
                        [np.max(_pts) for _pts in pts_t]))
 
 
+def fill_array(dstarr, order, r, g, b, a):
+    """Fill array dstarr with a color value. order defines the color planes
+    in the array.  (r, g, b, a) are expected to be in the range 0..1 and
+    are scaled to the appropriate values.
+
+    dstarr can be a 2D or 3D array.
+    """
+    # TODO: can we make this more efficient?
+    dtype = dstarr.dtype
+    maxv = np.iinfo(dtype).max
+    bgval = dict(A=int(maxv * a), R=int(maxv * r), G=int(maxv * g),
+                 B=int(maxv * b))
+    bgtup = tuple([bgval[order[i]] for i in range(len(order))])
+    if dtype is np.uint8 and len(bgtup) == 4:
+        # optimiztion
+        bgtup = np.array(bgtup, dtype=dtype).view(np.uint32)[0]
+        dstarr = dstarr.view(np.uint32)
+
+    dstarr[..., :] = bgtup
+
+
+def make_filled_array(shp, dtype, order, r, g, b, a):
+    """Return a filled array with a color value. order defines the color
+    planes in the array.  (r, g, b, a) are expected to be in the range
+    0..1 and are scaled to the appropriate values.
+
+    shp can define a 2D or 3D array.
+    """
+    # TODO: can we make this more efficient?
+    maxv = np.iinfo(dtype).max
+    bgval = dict(A=int(maxv * a), R=int(maxv * r), G=int(maxv * g),
+                 B=int(maxv * b))
+    bgtup = tuple([bgval[order[i]] for i in range(len(order))])
+    if dtype is np.uint8 and len(bgtup) == 4:
+        # optimiztion when dealing with 32-bit RGBA arrays
+        fill_val = np.array(bgtup, dtype=dtype).view(np.uint32)
+        rgba = np.zeros(shp, dtype=dtype)
+        rgba_i = rgba.view(np.uint32)
+        rgba_i[:] = fill_val
+        return rgba
+    return np.full(shp, bgtup, dtype=dtype)
+
 # END
