@@ -67,6 +67,7 @@ class Star(object):
     def __setitem__(self, key, value):
         self.starInfo[key] = value
 
+    # TODO: Should deprecate this and encourage __contains__ like Python dict
     def has_key(self, key):
         return key in self.starInfo
 
@@ -97,16 +98,16 @@ class AstroPyCatalogServer(object):
     def toStar(self, data, ext, magfield):
         try:
             mag = float(data[magfield])
-        except:
+        except Exception:
             mag = 0.0
 
         # Make sure we have at least these Ginga standard fields defined
-        d = {'name':        data[ext['id']],
-             'ra_deg':      float(data[ext['ra']]),
-             'dec_deg':     float(data[ext['dec']]),
-             'mag':         mag,
-             'preference':  0.0,
-             'priority':    0,
+        d = {'name': data[ext['id']],
+             'ra_deg': float(data[ext['ra']]),
+             'dec_deg': float(data[ext['dec']]),
+             'mag': mag,
+             'preference': 0.0,
+             'priority': 0,
              'description': 'fake magnitude'}
         data.update(d)
         data['ra'] = wcs.raDegToString(data['ra_deg'])
@@ -298,16 +299,16 @@ class PyVOCatalogServer(object):
     def toStar(self, data, ext, magfield):
         try:
             mag = float(data[magfield])
-        except:
+        except Exception:
             mag = 0.0
 
         # Make sure we have at least these Ginga standard fields defined
-        d = {'name':        data[ext['id']],
-             'ra_deg':      float(data[ext['ra']]),
-             'dec_deg':     float(data[ext['dec']]),
-             'mag':         mag,
-             'preference':  0.0,
-             'priority':    0,
+        d = {'name': data[ext['id']],
+             'ra_deg': float(data[ext['ra']]),
+             'dec_deg': float(data[ext['dec']]),
+             'mag': mag,
+             'preference': 0.0,
+             'priority': 0,
              'description': 'fake magnitude'}
         data.update(d)
         data['ra'] = wcs.raDegToString(data['ra_deg'])
@@ -643,7 +644,7 @@ class CatalogServer(URLServer):
         self.logger.debug("offset=%d" % (offset))
 
         results = []
-        table = [lines[offset-2]]
+        table = [lines[offset - 2]]
 
         for line in lines[offset:]:
             line = line.strip()
