@@ -135,6 +135,9 @@ class KapteynWCS(common.BaseWCS):
 
     def datapt_to_wcspt(self, datapt, coords='data', naxispath=None):
 
+        # force to array representation
+        datapt = np.asarray(datapt)
+
         # Kapteyn's WCS needs pixels referenced from 1
         if coords == 'data':
             datapt = datapt + 1.0
@@ -160,6 +163,9 @@ class KapteynWCS(common.BaseWCS):
 
     def wcspt_to_datapt(self, wcspt, coords='data', naxispath=None):
 
+        # force to array representation
+        wcspt = np.asarray(wcspt)
+
         if naxispath is not None:
             n = len(naxispath)
             if n > 0:
