@@ -702,10 +702,10 @@ class ScrollBar(WidgetBase):
                  classes=self.get_css_classes(fmt='str'),
                  styles=self.get_css_styles(fmt='str'))
         if self.orientation == 'vertical':
-            d['vert'] = 'true'
+            d['vert'] = 'false'
             d['width'], d['height'] = self.thickness, "'100%'"
         else:
-            d['vert'] = 'false'
+            d['vert'] = 'true'
             d['width'], d['height'] = "'100%'", self.thickness
 
         return self.html_template % d
@@ -1402,6 +1402,9 @@ class ContainerBase(WidgetBase):
     def get_children(self):
         return self.children
 
+    def num_children(self):
+        return len(self.children)
+
     def render(self):
         return self.render_children()
 
@@ -2067,7 +2070,6 @@ class Menu(ContainerBase):
 
         if self.widget is not None:
             return self.html_template1 % d
-
         return self.html_template2 % d
 
 
@@ -2507,6 +2509,9 @@ class Application(Callback.Callbacks):
     def mainloop(self, no_ioloop=False):
         self.start(no_ioloop=no_ioloop)
 
+    def quit(self):
+        self.stop()
+
 
 class Dialog(ContainerBase):
 
